@@ -262,13 +262,10 @@ class accuinsight(object):
             if self.feature_name is None:
                 try:
                     feature_name = get.feature_name(self.save_path, self.StorageInfo, self.target_name)
-                    
-                    print('1: ', feature_name)
-                    
+
                 except:
                     pass      # when user did not use <get_file> or <set_feature> function
             else:
-                print('2: ', self.feature_name)
                 feature_name = self.feature_name
         else:
             shap_on = False
