@@ -76,5 +76,5 @@ DB_CONNECT_DB = 'modeler'
 DB_CONNECT_CHARSET = 'utf8'
 
 BACK_END_API_URI = ''
-BACK_END_API_URL = 'api.accu'
+BACK_END_API_URL = 'modeler-api.accu'
 BACK_END_API_PORT = '8080'
